@@ -7,6 +7,7 @@ import argparse
 import json
 import os
 import subprocess
+import sys
 
 import gnssrefl.gps as g
 
@@ -20,14 +21,15 @@ def main():
     parser.add_argument("long", help="longitude (degrees)", type=float)
     parser.add_argument("height", help="ellipsoidal height (meters)", type=float)
 # these are the optional inputs 
-    parser.add_argument("-e1", , default=None, type=int, help="lower limit elevation angle")
-    parser.add_argument("-e2",  default=None, type=int, help="upper limit elevation angle")
-    parser.add_argument("-h1",  default=None, type=float, help="lower limit reflector height (m)")
-    parser.add_argument("-h2",  default=None, type=float, help="upper limit reflector height (m)")
-    parser.add_argument("-nr1", default=None, type=float, help="lower limit noise region for QC(m)")
-    parser.add_argument("-nr2",  default=None, type=float, help="upper limit noise region for QC(m)")
-    parser.add_argument("-peak2noise",  default=None, type=float, help="peak to noise ratio used for QC")
+    parser.add_argument("-e1", default=None, type=int, help="lower limit elevation angle")
+    parser.add_argument("-e2", default=None, type=int, help="upper limit elevation angle")
+    parser.add_argument("-h1", default=None, type=float, help="lower limit reflector height (m)")
+    parser.add_argument("-h2", default=None, type=float, help="upper limit reflector height (m)")
+    parser.add_argument("-nr1",default=None, type=float, help="lower limit noise region for QC(m)")
+    parser.add_argument("-nr2",default=None, type=float, help="upper limit noise region for QC(m)")
+    parser.add_argument("-peak2noise", default=None, type=float, help="peak to noise ratio used for QC")
     parser.add_argument("-allfreq", default=None, type=str, help="set to True to include all GNSS")
+    parser.add_argument("-xyz", default=None, type=str, help="set to True if using Cartesian coordinates")
     args = parser.parse_args()
 #
 
@@ -37,11 +39,20 @@ def main():
 # rename the user inputs into variables
 #
     station = args.station
+    NS = len(station)
+    if (NS != 4):
+        print('station name must be four characters long. Exiting.')
+        sys.exit()
+
 # location of the site - does not have to be very good.  within 100 meters is fine
     Lat = args.lat
     Long = args.long
     Height = args.height
 
+    if args.xyz == 'True':
+        xyz = [Lat, Long, Height]
+        Lat,Long,Height = g.xyz2llhd(xyz)
+
 # start the lsp dictionary
     lsp={}
     lsp['station'] = station
@@ -111,7 +122,8 @@ def main():
         # choose GPS as the default
         lsp['freqs'] = [1, 20, 5]; lsp['reqAmp'] = [6, 6,6]
     else:
-        lsp['freqs'] = [1, 20, 5, 101, 102, 201, 205, 206,207,208,302, 306,307]; lsp['reqAmp'] = [6, 6,6,6,6,6,6,6,6,6,6,6,6]
+        # 307 was making it crash.  did not check as to why
+        lsp['freqs'] = [1, 20, 5, 101, 102, 201, 205, 206,207,208,302, 306]; lsp['reqAmp'] = [6, 6,6,6,6,6,6,6,6,6,6,6]
 # use refraction correction
     lsp['refraction'] = True
 
