@@ -30,7 +30,7 @@ def read_snr_simple(obsfile):
     try:
         f = np.genfromtxt(obsfile,comments='%')
         r,c = f.shape
-        print('read_snr_simple, Number of rows:', r, ' Number of columns:',c)
+        #print('read_snr_simple, Number of rows:', r, ' Number of columns:',c)
         sat = f[:,0]; ele = f[:,1]; azi = f[:,2]; t =  f[:,3]
         edot =  f[:,4]; s1 = f[:,6]; s2 = f[:,7]; s6 = f[:,5]
         s1 = np.power(10,(s1/20))  
@@ -104,7 +104,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     minNumPts = 20 
     #noise region for LSP QC. these are meters
     NReg = [minH, maxH]
-    print('noise region', NReg)
+    print('Refl. Ht. Noise Region used: ', NReg)
     # for quickLook, we use the four geographic quadrants - these are azimuth angles in degrees
     azval = [270, 360, 180, 270, 0, 90, 90, 180]
     naz = int(len(azval)/2) # number of azimuth pairs
@@ -120,10 +120,11 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
         print('>>>> The snr file exists ',obsfile)
     else:
         if True:
-            print('look for the SNR file elsewhere')
+            print('looking for the SNR file on disk')
             obsfile, obsfileCmp, snre =  g.define_and_xz_snr(station,year,doy,snr_type)
             if snre:
-                print('file exists on disk')
+                dkfjaklj = True
+                #print('file exists on disk')
             else:
                 print('>>>> The SNR the file does not exist ',obsfile)
                 print('I will try to pick up a RINEX file ')
@@ -137,9 +138,11 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                     print('the RINEX file did not exist, had no SNR data, or failed to convert, so exiting.')
     allGood,sat,ele,azi,t,edot,s1,s2,s5,s6,s7,s8,snrE = read_snr_simple(obsfile)
     if allGood == 1:
+        # make output file for the quickLook RRH values, just so you can give them a quick look see
+        rhout = open('rh.txt','w+')
         amax = 0
         minEdataset = np.min(ele)
-        print('min elevation angle for this dataset ', minEdataset)
+        print('minimum elevation angle (degrees) for this dataset: ', minEdataset)
         if minEdataset > (e1+0.5):
             print('It looks like the receiver had an elevation mask')
             e1 = minEdataset
@@ -147,7 +150,9 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
             fig = Figure(figsize=(10,6), dpi=120)
             axes = fig.subplots(2, 2)
         else:
-            plt.figure()
+            #plt.figure()
+            # trying to help Kelly
+            plt.figure(figsize=(10,6))
         for a in range(naz):
             if not webapp:
                 plt.subplot(2,2,bz[a])
@@ -172,7 +177,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                         Noise = 1; iAzim = 0 # made up numbers
                     if (delT < delTmax) & (eminObs < (e1 + ediff)) & (emaxObs > (e2 - ediff)) & (maxAmp > requireAmp) & (maxAmp/Noise > PkNoise):
                         T = g.nicerTime(UTCtime)
-                        print('SUCCESS Azimuth {0:3.0f} RH {1:6.3f} m, Sat {2:3.0f} Freq {3:3.0f} Amp {4:4.1f} PkNoise {5:3.1f} UTC {6:5s} '.format( 
+                        rhout.write('SUCCESS Azimuth {0:3.0f} RH {1:6.3f} m, Sat {2:3.0f} Freq {3:3.0f} Amp {4:4.1f} PkNoise {5:3.1f} UTC {6:5s} \n '.format( 
                             avgAzim,maxF,satNu,f,maxAmp,maxAmp/Noise,T))
                         if not webapp:
                             plt.plot(px,pz,linewidth=1.5)
@@ -190,6 +195,9 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
             if (a == 3) or (a==1):
                 plt.xlabel('reflector height (m)')
         plt.suptitle(tt, fontsize=12)
+
+        rhout.close()
+        print('Reflector Height results are stored in a file called rh.txt')
         if webapp:
             fig.savefig('temp.png', format="png")
         else:
